This function is a shiny module to xxx
This function is written with specifications of the package MagellanNTK so
as to be easily integrated into workflfow compliant with MagellanNTK.
Value
As for all modules used with MagellanNTK, the return value is a
list() of two items:
trigger : xxx
value: In this case, it contains a list() of three slots:
ll.var: a list() of instances of the class
Filtering,ll.query: a list of
character()which describe the queries in natural language,ll.widgets.value: a list of the values of widgets.
Examples
if (interactive()){
data(Exp1_R25_pept, package = "DaparToolshedData")
obj <- Exp1_R25_pept[seq_len(100)]
shiny::runApp(mod_Pept_Imputation(obj, 1))
}