This manual page describes manipulation methods using list objects. In
index or name i can be specified to define the array (by name of
index) on which to operate.
The following functions are currently available:
keepDatasets(object, range)keep datasets in object which are in rangeaddDatasets(object, dataset, name)add the 'dataset' to the object (of type list)Save(object, file)stores the object to a .RData file
This function appends a dataset in the list with customization if necessary
This function deletes the items not included in the range parameter