This shiny module offers a UI to select a subset of a dataset and superimpose quantitative values of this selection on the complete plot Three modes of selection are implemented:
'Protein list': xxx,
'Random': xxx,
'Specific column': xxx
Examples
if (interactive()){
data(Exp1_R25_prot, package = "DaparToolshedData")
shiny::runApp(mod_tracker(Exp1_R25_prot))
}